## Typing stubs for pony

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`pony`](https://github.com/ponyorm/pony) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `pony`. This version of
`types-pony` aims to provide accurate annotations for
`pony==0.7.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/pony`](https://github.com/python/typeshed/tree/main/stubs/pony)
directory.

This package was tested with
mypy 1.16.1,
pyright 1.1.403,
and pytype 2024.10.11.
It was generated from typeshed commit
[`cc9cb918e638c2b83358bd9b4d52fd87f4349976`](https://github.com/python/typeshed/commit/cc9cb918e638c2b83358bd9b4d52fd87f4349976).